Module: Aws::MWAAServerless::Errors
- Extended by:
- Errors::DynamicErrors
- Defined in:
- lib/aws-sdk-mwaaserverless/errors.rb
Overview
When MWAAServerless returns an error response, the Ruby SDK constructs and raises an error. These errors all extend Aws::MWAAServerless::Errors::ServiceError < Errors::ServiceError
You can rescue all MWAAServerless errors using ServiceError:
begin
# do stuff
rescue Aws::MWAAServerless::Errors::ServiceError
# rescues all MWAAServerless API errors
end
## Request Context ServiceError objects have a #context method that returns information about the request that generated the error. See Seahorse::Client::RequestContext for more information.
## Error Classes
Additionally, error classes are dynamically generated for service errors based on the error code if they are not defined above.
Defined Under Namespace
Classes: AccessDeniedException, ConflictException, InternalServerException, OperationTimeoutException, ResourceNotFoundException, ServiceQuotaExceededException, ThrottlingException, ValidationException