Class: Aws::MWAAServerless::Types::ConflictException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mwaaserverless/types.rb

Overview

You cannot create a resource that already exists, or the resource is in a state that prevents the requested operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


67
68
69
70
71
72
73
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 67

class ConflictException < Struct.new(
  :message,
  :resource_id,
  :resource_type)
  SENSITIVE = []
  include Aws::Structure
end

#resource_idString

The unique identifier of the resource.

Returns:

  • (String)


67
68
69
70
71
72
73
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 67

class ConflictException < Struct.new(
  :message,
  :resource_id,
  :resource_type)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The type of the resource.

Returns:

  • (String)


67
68
69
70
71
72
73
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 67

class ConflictException < Struct.new(
  :message,
  :resource_id,
  :resource_type)
  SENSITIVE = []
  include Aws::Structure
end