Class: Aws::MWAAServerless::Types::CreateWorkflowRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MWAAServerless::Types::CreateWorkflowRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mwaaserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#definition_s3_location ⇒ Types::DefinitionS3Location
The Amazon S3 location where the workflow definition file is stored.
-
#description ⇒ String
An optional description of the workflow that you can use to provide additional context about the workflow’s purpose and functionality.
-
#encryption_configuration ⇒ Types::EncryptionConfiguration
The configuration for encrypting workflow data at rest and in transit.
-
#engine_version ⇒ Integer
The version of the Amazon Managed Workflows for Apache Airflow Serverless engine that you want to use for this workflow.
-
#logging_configuration ⇒ Types::LoggingConfiguration
The configuration for workflow logging.
-
#name ⇒ String
The name of the workflow.
-
#network_configuration ⇒ Types::NetworkConfiguration
Network configuration for the workflow execution environment, including VPC security groups and subnets for secure network access.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that Amazon Managed Workflows for Apache Airflow Serverless assumes when executing the workflow.
-
#tags ⇒ Hash<String,String>
A map of tags to assign to the workflow resource.
-
#trigger_mode ⇒ String
The trigger mode for the workflow execution.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. This token prevents duplicate workflow creation requests.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 146 class CreateWorkflowRequest < Struct.new( :name, :client_token, :definition_s3_location, :role_arn, :description, :encryption_configuration, :logging_configuration, :engine_version, :network_configuration, :tags, :trigger_mode) SENSITIVE = [] include Aws::Structure end |
#definition_s3_location ⇒ Types::DefinitionS3Location
The Amazon S3 location where the workflow definition file is stored. This must point to a valid YAML file that defines the workflow structure using supported Amazon Web Services operators and tasks. Amazon Managed Workflows for Apache Airflow Serverless takes a snapshot of the definition at creation time, so subsequent changes to the Amazon S3 object will not affect the workflow unless you create a new version. In your YAML definition, include task dependencies, scheduling information, and operator configurations that are compatible with the Amazon Managed Workflows for Apache Airflow Serverless execution environment.
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 146 class CreateWorkflowRequest < Struct.new( :name, :client_token, :definition_s3_location, :role_arn, :description, :encryption_configuration, :logging_configuration, :engine_version, :network_configuration, :tags, :trigger_mode) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
An optional description of the workflow that you can use to provide additional context about the workflow’s purpose and functionality.
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 146 class CreateWorkflowRequest < Struct.new( :name, :client_token, :definition_s3_location, :role_arn, :description, :encryption_configuration, :logging_configuration, :engine_version, :network_configuration, :tags, :trigger_mode) SENSITIVE = [] include Aws::Structure end |
#encryption_configuration ⇒ Types::EncryptionConfiguration
The configuration for encrypting workflow data at rest and in transit. Specifies the encryption type and optional KMS key for customer-managed encryption.
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 146 class CreateWorkflowRequest < Struct.new( :name, :client_token, :definition_s3_location, :role_arn, :description, :encryption_configuration, :logging_configuration, :engine_version, :network_configuration, :tags, :trigger_mode) SENSITIVE = [] include Aws::Structure end |
#engine_version ⇒ Integer
The version of the Amazon Managed Workflows for Apache Airflow Serverless engine that you want to use for this workflow. This determines the feature set, supported operators, and execution environment capabilities available to your workflow. Amazon Managed Workflows for Apache Airflow Serverless maintains backward compatibility across versions while introducing new features and improvements. Currently supports version 1 with plans for additional versions as the service evolves.
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 146 class CreateWorkflowRequest < Struct.new( :name, :client_token, :definition_s3_location, :role_arn, :description, :encryption_configuration, :logging_configuration, :engine_version, :network_configuration, :tags, :trigger_mode) SENSITIVE = [] include Aws::Structure end |
#logging_configuration ⇒ Types::LoggingConfiguration
The configuration for workflow logging. Specifies the CloudWatch log group where workflow execution logs are stored. Amazon Managed Workflows for Apache Airflow Serverless automatically exports worker logs and task-level information to the specified log group in your account using remote logging functionality. This provides comprehensive observability for debugging and monitoring workflow execution across the distributed, serverless environment.
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 146 class CreateWorkflowRequest < Struct.new( :name, :client_token, :definition_s3_location, :role_arn, :description, :encryption_configuration, :logging_configuration, :engine_version, :network_configuration, :tags, :trigger_mode) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the workflow. You must use unique workflow names within your Amazon Web Services account. The service generates a unique identifier that is appended to ensure temporal uniqueness across the account lifecycle.
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 146 class CreateWorkflowRequest < Struct.new( :name, :client_token, :definition_s3_location, :role_arn, :description, :encryption_configuration, :logging_configuration, :engine_version, :network_configuration, :tags, :trigger_mode) SENSITIVE = [] include Aws::Structure end |
#network_configuration ⇒ Types::NetworkConfiguration
Network configuration for the workflow execution environment, including VPC security groups and subnets for secure network access. When specified, Amazon Managed Workflows for Apache Airflow Serverless deploys ECS worker tasks in your customer VPC to provide secure connectivity to your resources. If not specified, tasks run in the service’s default worker VPC with network isolation from other customers. This configuration enables secure access to VPC-only resources like RDS databases or private endpoints.
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 146 class CreateWorkflowRequest < Struct.new( :name, :client_token, :definition_s3_location, :role_arn, :description, :encryption_configuration, :logging_configuration, :engine_version, :network_configuration, :tags, :trigger_mode) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that Amazon Managed Workflows for Apache Airflow Serverless assumes when executing the workflow. This role must have the necessary permissions to access the required Amazon Web Services services and resources that your workflow tasks will interact with. The role is used for task execution in the isolated, multi-tenant environment and should follow the principle of least privilege. Amazon Managed Workflows for Apache Airflow Serverless validates role access during workflow creation but runtime permission checks are performed by the target services.
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 146 class CreateWorkflowRequest < Struct.new( :name, :client_token, :definition_s3_location, :role_arn, :description, :encryption_configuration, :logging_configuration, :engine_version, :network_configuration, :tags, :trigger_mode) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A map of tags to assign to the workflow resource. Tags are key-value pairs that are used for resource organization and cost allocation.
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 146 class CreateWorkflowRequest < Struct.new( :name, :client_token, :definition_s3_location, :role_arn, :description, :encryption_configuration, :logging_configuration, :engine_version, :network_configuration, :tags, :trigger_mode) SENSITIVE = [] include Aws::Structure end |
#trigger_mode ⇒ String
The trigger mode for the workflow execution.
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 146 class CreateWorkflowRequest < Struct.new( :name, :client_token, :definition_s3_location, :role_arn, :description, :encryption_configuration, :logging_configuration, :engine_version, :network_configuration, :tags, :trigger_mode) SENSITIVE = [] include Aws::Structure end |