Class: Aws::MWAAServerless::Types::CreateWorkflowResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MWAAServerless::Types::CreateWorkflowResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mwaaserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp when the workflow was created, in ISO 8601 date-time format.
-
#is_latest_version ⇒ Boolean
A Boolean flag that indicates whether this workflow version is the latest version of the workflow.
-
#revision_id ⇒ String
A unique identifier for this revision of the workflow configuration.
-
#warnings ⇒ Array<String>
Warning messages generated during workflow creation.
-
#workflow_arn ⇒ String
The Amazon Resource Name (ARN) of the newly created workflow.
-
#workflow_status ⇒ String
The current status of the workflow.
-
#workflow_version ⇒ String
The version identifier of the workflow.
Instance Attribute Details
#created_at ⇒ Time
The timestamp when the workflow was created, in ISO 8601 date-time format.
240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 240 class CreateWorkflowResponse < Struct.new( :workflow_arn, :created_at, :revision_id, :workflow_status, :workflow_version, :is_latest_version, :warnings) SENSITIVE = [] include Aws::Structure end |
#is_latest_version ⇒ Boolean
A Boolean flag that indicates whether this workflow version is the latest version of the workflow.
240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 240 class CreateWorkflowResponse < Struct.new( :workflow_arn, :created_at, :revision_id, :workflow_status, :workflow_version, :is_latest_version, :warnings) SENSITIVE = [] include Aws::Structure end |
#revision_id ⇒ String
A unique identifier for this revision of the workflow configuration. This ID changes when the workflow is updated and you can use it for optimistic concurrency control in update operations. The revision ID helps prevent conflicting updates and ensures that updates are applied to the expected version of the workflow configuration.
240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 240 class CreateWorkflowResponse < Struct.new( :workflow_arn, :created_at, :revision_id, :workflow_status, :workflow_version, :is_latest_version, :warnings) SENSITIVE = [] include Aws::Structure end |
#warnings ⇒ Array<String>
Warning messages generated during workflow creation.
240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 240 class CreateWorkflowResponse < Struct.new( :workflow_arn, :created_at, :revision_id, :workflow_status, :workflow_version, :is_latest_version, :warnings) SENSITIVE = [] include Aws::Structure end |
#workflow_arn ⇒ String
The Amazon Resource Name (ARN) of the newly created workflow. This ARN uniquely identifies the workflow resource.
240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 240 class CreateWorkflowResponse < Struct.new( :workflow_arn, :created_at, :revision_id, :workflow_status, :workflow_version, :is_latest_version, :warnings) SENSITIVE = [] include Aws::Structure end |
#workflow_status ⇒ String
The current status of the workflow. Possible values are READY
(workflow is ready to run) and DELETING (workflow is being
deleted).
240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 240 class CreateWorkflowResponse < Struct.new( :workflow_arn, :created_at, :revision_id, :workflow_status, :workflow_version, :is_latest_version, :warnings) SENSITIVE = [] include Aws::Structure end |
#workflow_version ⇒ String
The version identifier of the workflow. This is a service-generated alphanumeric string that uniquely identifies this version of the workflow. Amazon Managed Workflows for Apache Airflow Serverless uses a version-first approach where each workflow can have multiple immutable versions, which allows you to maintain different configurations and roll back to previous versions as needed. The version identifier is used in ARNs and API operations to reference specific workflow versions.
240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 240 class CreateWorkflowResponse < Struct.new( :workflow_arn, :created_at, :revision_id, :workflow_status, :workflow_version, :is_latest_version, :warnings) SENSITIVE = [] include Aws::Structure end |