Class: Aws::MWAAServerless::Types::DefinitionS3Location

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mwaaserverless/types.rb

Overview

Specifies the Amazon S3 location of a workflow definition file. This structure contains the bucket name, object key, and optional version ID for the workflow definition. Amazon Managed Workflows for Apache Airflow Serverless takes a snapshot of the definition file at the time of workflow creation or update, ensuring that the workflow behavior remains consistent even if the source file is modified. The definition must be a valid YAML file that uses supported Amazon Web Services operators and Amazon Managed Workflows for Apache Airflow Serverless syntax.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The name of the Amazon S3 bucket that contains the workflow definition file.

Returns:

  • (String)


278
279
280
281
282
283
284
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 278

class DefinitionS3Location < Struct.new(
  :bucket,
  :object_key,
  :version_id)
  SENSITIVE = []
  include Aws::Structure
end

#object_keyString

The key (name) of the workflow definition file within the S3 bucket.

Returns:

  • (String)


278
279
280
281
282
283
284
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 278

class DefinitionS3Location < Struct.new(
  :bucket,
  :object_key,
  :version_id)
  SENSITIVE = []
  include Aws::Structure
end

#version_idString

Optional. The version ID of the workflow definition file in Amazon S3. If not specified, the latest version is used.

Returns:

  • (String)


278
279
280
281
282
283
284
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 278

class DefinitionS3Location < Struct.new(
  :bucket,
  :object_key,
  :version_id)
  SENSITIVE = []
  include Aws::Structure
end