Class: Aws::MWAAServerless::Types::EncryptionConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::MWAAServerless::Types::EncryptionConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mwaaserverless/types.rb
Overview
Configuration for encrypting workflow data at rest and in transit. Amazon Managed Workflows for Apache Airflow Serverless provides comprehensive encryption capabilities to protect sensitive workflow data, parameters, and execution logs. When using customer-managed keys, the service integrates with Amazon Web Services KMS to provide fine-grained access control and audit capabilities. Encryption is applied consistently across the distributed execution environment including task containers, metadata storage, and log streams.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#kms_key_id ⇒ String
The ID or ARN of the Amazon Web Services KMS key to use for encryption.
-
#type ⇒ String
The type of encryption to use.
Instance Attribute Details
#kms_key_id ⇒ String
The ID or ARN of the Amazon Web Services KMS key to use for encryption. Required when ‘Type` is `CUSTOMER_MANAGED_KEY`.
311 312 313 314 315 316 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 311 class EncryptionConfiguration < Struct.new( :type, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of encryption to use. Values are ‘AWS_MANAGED_KEY` (Amazon Web Services manages the encryption key) or `CUSTOMER_MANAGED_KEY` (you provide a KMS key).
311 312 313 314 315 316 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 311 class EncryptionConfiguration < Struct.new( :type, :kms_key_id) SENSITIVE = [] include Aws::Structure end |