Class: Aws::MWAAServerless::Types::GetTaskInstanceResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MWAAServerless::Types::GetTaskInstanceResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mwaaserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attempt_number ⇒ Integer
The attempt number for this task instance.
-
#duration_in_seconds ⇒ Integer
The duration of the task instance execution in seconds.
-
#ended_at ⇒ Time
The timestamp when the task instance completed execution, in ISO 8601 date-time format.
-
#error_message ⇒ String
The error message if the task instance failed.
-
#log_stream ⇒ String
The CloudWatch log stream name for this task instance execution.
-
#modified_at ⇒ Time
The timestamp when the task instance was last modified, in ISO 8601 date-time format.
-
#operator_name ⇒ String
The name of the Apache Airflow operator used for this task instance.
-
#run_id ⇒ String
The unique identifier of the workflow run that contains this task instance.
-
#started_at ⇒ Time
The timestamp when the task instance started execution, in ISO 8601 date-time format.
-
#status ⇒ String
The current status of the task instance.
-
#task_id ⇒ String
The unique identifier of the task definition within the workflow.
-
#task_instance_id ⇒ String
The unique identifier of this task instance.
-
#workflow_arn ⇒ String
The Amazon Resource Name (ARN) of the workflow that contains this task instance.
-
#workflow_version ⇒ String
The version of the workflow that contains this task instance.
-
#xcom ⇒ Hash<String,String>
Cross-communication data exchanged between tasks in the workflow execution.
Instance Attribute Details
#attempt_number ⇒ Integer
The attempt number for this task instance.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 445 class GetTaskInstanceResponse < Struct.new( :workflow_arn, :run_id, :task_instance_id, :workflow_version, :status, :duration_in_seconds, :operator_name, :modified_at, :ended_at, :started_at, :attempt_number, :error_message, :task_id, :log_stream, :xcom) SENSITIVE = [] include Aws::Structure end |
#duration_in_seconds ⇒ Integer
The duration of the task instance execution in seconds. This value is null if the task is not complete.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 445 class GetTaskInstanceResponse < Struct.new( :workflow_arn, :run_id, :task_instance_id, :workflow_version, :status, :duration_in_seconds, :operator_name, :modified_at, :ended_at, :started_at, :attempt_number, :error_message, :task_id, :log_stream, :xcom) SENSITIVE = [] include Aws::Structure end |
#ended_at ⇒ Time
The timestamp when the task instance completed execution, in ISO 8601 date-time format. This value is null if the task is not complete.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 445 class GetTaskInstanceResponse < Struct.new( :workflow_arn, :run_id, :task_instance_id, :workflow_version, :status, :duration_in_seconds, :operator_name, :modified_at, :ended_at, :started_at, :attempt_number, :error_message, :task_id, :log_stream, :xcom) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
The error message if the task instance failed. This value is null if the task completed successfully.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 445 class GetTaskInstanceResponse < Struct.new( :workflow_arn, :run_id, :task_instance_id, :workflow_version, :status, :duration_in_seconds, :operator_name, :modified_at, :ended_at, :started_at, :attempt_number, :error_message, :task_id, :log_stream, :xcom) SENSITIVE = [] include Aws::Structure end |
#log_stream ⇒ String
The CloudWatch log stream name for this task instance execution.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 445 class GetTaskInstanceResponse < Struct.new( :workflow_arn, :run_id, :task_instance_id, :workflow_version, :status, :duration_in_seconds, :operator_name, :modified_at, :ended_at, :started_at, :attempt_number, :error_message, :task_id, :log_stream, :xcom) SENSITIVE = [] include Aws::Structure end |
#modified_at ⇒ Time
The timestamp when the task instance was last modified, in ISO 8601 date-time format.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 445 class GetTaskInstanceResponse < Struct.new( :workflow_arn, :run_id, :task_instance_id, :workflow_version, :status, :duration_in_seconds, :operator_name, :modified_at, :ended_at, :started_at, :attempt_number, :error_message, :task_id, :log_stream, :xcom) SENSITIVE = [] include Aws::Structure end |
#operator_name ⇒ String
The name of the Apache Airflow operator used for this task instance.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 445 class GetTaskInstanceResponse < Struct.new( :workflow_arn, :run_id, :task_instance_id, :workflow_version, :status, :duration_in_seconds, :operator_name, :modified_at, :ended_at, :started_at, :attempt_number, :error_message, :task_id, :log_stream, :xcom) SENSITIVE = [] include Aws::Structure end |
#run_id ⇒ String
The unique identifier of the workflow run that contains this task instance.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 445 class GetTaskInstanceResponse < Struct.new( :workflow_arn, :run_id, :task_instance_id, :workflow_version, :status, :duration_in_seconds, :operator_name, :modified_at, :ended_at, :started_at, :attempt_number, :error_message, :task_id, :log_stream, :xcom) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The timestamp when the task instance started execution, in ISO 8601 date-time format. This value is null if the task has not started.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 445 class GetTaskInstanceResponse < Struct.new( :workflow_arn, :run_id, :task_instance_id, :workflow_version, :status, :duration_in_seconds, :operator_name, :modified_at, :ended_at, :started_at, :attempt_number, :error_message, :task_id, :log_stream, :xcom) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the task instance.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 445 class GetTaskInstanceResponse < Struct.new( :workflow_arn, :run_id, :task_instance_id, :workflow_version, :status, :duration_in_seconds, :operator_name, :modified_at, :ended_at, :started_at, :attempt_number, :error_message, :task_id, :log_stream, :xcom) SENSITIVE = [] include Aws::Structure end |
#task_id ⇒ String
The unique identifier of the task definition within the workflow.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 445 class GetTaskInstanceResponse < Struct.new( :workflow_arn, :run_id, :task_instance_id, :workflow_version, :status, :duration_in_seconds, :operator_name, :modified_at, :ended_at, :started_at, :attempt_number, :error_message, :task_id, :log_stream, :xcom) SENSITIVE = [] include Aws::Structure end |
#task_instance_id ⇒ String
The unique identifier of this task instance.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 445 class GetTaskInstanceResponse < Struct.new( :workflow_arn, :run_id, :task_instance_id, :workflow_version, :status, :duration_in_seconds, :operator_name, :modified_at, :ended_at, :started_at, :attempt_number, :error_message, :task_id, :log_stream, :xcom) SENSITIVE = [] include Aws::Structure end |
#workflow_arn ⇒ String
The Amazon Resource Name (ARN) of the workflow that contains this task instance.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 445 class GetTaskInstanceResponse < Struct.new( :workflow_arn, :run_id, :task_instance_id, :workflow_version, :status, :duration_in_seconds, :operator_name, :modified_at, :ended_at, :started_at, :attempt_number, :error_message, :task_id, :log_stream, :xcom) SENSITIVE = [] include Aws::Structure end |
#workflow_version ⇒ String
The version of the workflow that contains this task instance.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 445 class GetTaskInstanceResponse < Struct.new( :workflow_arn, :run_id, :task_instance_id, :workflow_version, :status, :duration_in_seconds, :operator_name, :modified_at, :ended_at, :started_at, :attempt_number, :error_message, :task_id, :log_stream, :xcom) SENSITIVE = [] include Aws::Structure end |
#xcom ⇒ Hash<String,String>
Cross-communication data exchanged between tasks in the workflow execution.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 445 class GetTaskInstanceResponse < Struct.new( :workflow_arn, :run_id, :task_instance_id, :workflow_version, :status, :duration_in_seconds, :operator_name, :modified_at, :ended_at, :started_at, :attempt_number, :error_message, :task_id, :log_stream, :xcom) SENSITIVE = [] include Aws::Structure end |