Class: Aws::MWAAServerless::Types::GetWorkflowResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mwaaserverless/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#codeTypes::Code

The Amazon S3 location of the code artifacts provided during workflow creation or update.

Returns:



570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 570

class GetWorkflowResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :name,
  :description,
  :created_at,
  :modified_at,
  :encryption_configuration,
  :logging_configuration,
  :engine_version,
  :workflow_status,
  :definition_s3_location,
  :code,
  :code_snapshotted_at,
  :schedule_configuration,
  :role_arn,
  :network_configuration,
  :trigger_mode,
  :workflow_definition)
  SENSITIVE = []
  include Aws::Structure
end

#code_snapshotted_atTime

The time at which the code artifacts were copied for this workflow, in ISO 8601 date-time format.

Returns:

  • (Time)


570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 570

class GetWorkflowResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :name,
  :description,
  :created_at,
  :modified_at,
  :encryption_configuration,
  :logging_configuration,
  :engine_version,
  :workflow_status,
  :definition_s3_location,
  :code,
  :code_snapshotted_at,
  :schedule_configuration,
  :role_arn,
  :network_configuration,
  :trigger_mode,
  :workflow_definition)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The timestamp when the workflow was created, in ISO 8601 date-time format.

Returns:

  • (Time)


570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 570

class GetWorkflowResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :name,
  :description,
  :created_at,
  :modified_at,
  :encryption_configuration,
  :logging_configuration,
  :engine_version,
  :workflow_status,
  :definition_s3_location,
  :code,
  :code_snapshotted_at,
  :schedule_configuration,
  :role_arn,
  :network_configuration,
  :trigger_mode,
  :workflow_definition)
  SENSITIVE = []
  include Aws::Structure
end

#definition_s3_locationTypes::DefinitionS3Location

The Amazon S3 location of the workflow definition file.



570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 570

class GetWorkflowResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :name,
  :description,
  :created_at,
  :modified_at,
  :encryption_configuration,
  :logging_configuration,
  :engine_version,
  :workflow_status,
  :definition_s3_location,
  :code,
  :code_snapshotted_at,
  :schedule_configuration,
  :role_arn,
  :network_configuration,
  :trigger_mode,
  :workflow_definition)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the workflow.

Returns:

  • (String)


570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 570

class GetWorkflowResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :name,
  :description,
  :created_at,
  :modified_at,
  :encryption_configuration,
  :logging_configuration,
  :engine_version,
  :workflow_status,
  :definition_s3_location,
  :code,
  :code_snapshotted_at,
  :schedule_configuration,
  :role_arn,
  :network_configuration,
  :trigger_mode,
  :workflow_definition)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_configurationTypes::EncryptionConfiguration

The encryption configuration for the workflow.



570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 570

class GetWorkflowResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :name,
  :description,
  :created_at,
  :modified_at,
  :encryption_configuration,
  :logging_configuration,
  :engine_version,
  :workflow_status,
  :definition_s3_location,
  :code,
  :code_snapshotted_at,
  :schedule_configuration,
  :role_arn,
  :network_configuration,
  :trigger_mode,
  :workflow_definition)
  SENSITIVE = []
  include Aws::Structure
end

#engine_versionInteger

The version of the Amazon Managed Workflows for Apache Airflow Serverless engine that this workflow uses.

Returns:

  • (Integer)


570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 570

class GetWorkflowResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :name,
  :description,
  :created_at,
  :modified_at,
  :encryption_configuration,
  :logging_configuration,
  :engine_version,
  :workflow_status,
  :definition_s3_location,
  :code,
  :code_snapshotted_at,
  :schedule_configuration,
  :role_arn,
  :network_configuration,
  :trigger_mode,
  :workflow_definition)
  SENSITIVE = []
  include Aws::Structure
end

#logging_configurationTypes::LoggingConfiguration

The logging configuration for the workflow.



570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 570

class GetWorkflowResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :name,
  :description,
  :created_at,
  :modified_at,
  :encryption_configuration,
  :logging_configuration,
  :engine_version,
  :workflow_status,
  :definition_s3_location,
  :code,
  :code_snapshotted_at,
  :schedule_configuration,
  :role_arn,
  :network_configuration,
  :trigger_mode,
  :workflow_definition)
  SENSITIVE = []
  include Aws::Structure
end

#modified_atTime

The timestamp when the workflow was last modified, in ISO 8601 date-time format.

Returns:

  • (Time)


570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 570

class GetWorkflowResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :name,
  :description,
  :created_at,
  :modified_at,
  :encryption_configuration,
  :logging_configuration,
  :engine_version,
  :workflow_status,
  :definition_s3_location,
  :code,
  :code_snapshotted_at,
  :schedule_configuration,
  :role_arn,
  :network_configuration,
  :trigger_mode,
  :workflow_definition)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the workflow.

Returns:

  • (String)


570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 570

class GetWorkflowResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :name,
  :description,
  :created_at,
  :modified_at,
  :encryption_configuration,
  :logging_configuration,
  :engine_version,
  :workflow_status,
  :definition_s3_location,
  :code,
  :code_snapshotted_at,
  :schedule_configuration,
  :role_arn,
  :network_configuration,
  :trigger_mode,
  :workflow_definition)
  SENSITIVE = []
  include Aws::Structure
end

#network_configurationTypes::NetworkConfiguration

The network configuration for the workflow execution environment.



570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 570

class GetWorkflowResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :name,
  :description,
  :created_at,
  :modified_at,
  :encryption_configuration,
  :logging_configuration,
  :engine_version,
  :workflow_status,
  :definition_s3_location,
  :code,
  :code_snapshotted_at,
  :schedule_configuration,
  :role_arn,
  :network_configuration,
  :trigger_mode,
  :workflow_definition)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of the IAM role used for workflow execution.

Returns:

  • (String)


570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 570

class GetWorkflowResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :name,
  :description,
  :created_at,
  :modified_at,
  :encryption_configuration,
  :logging_configuration,
  :engine_version,
  :workflow_status,
  :definition_s3_location,
  :code,
  :code_snapshotted_at,
  :schedule_configuration,
  :role_arn,
  :network_configuration,
  :trigger_mode,
  :workflow_definition)
  SENSITIVE = []
  include Aws::Structure
end

#schedule_configurationTypes::ScheduleConfiguration

The schedule configuration for the workflow, including cron expressions for automated execution. Amazon Managed Workflows for Apache Airflow Serverless uses EventBridge Scheduler for cost-effective, timezone-aware scheduling. When a workflow includes schedule information in its YAML definition, the service automatically configures the appropriate triggers for automated execution. Only one version of a workflow can have an active schedule at any given time.



570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 570

class GetWorkflowResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :name,
  :description,
  :created_at,
  :modified_at,
  :encryption_configuration,
  :logging_configuration,
  :engine_version,
  :workflow_status,
  :definition_s3_location,
  :code,
  :code_snapshotted_at,
  :schedule_configuration,
  :role_arn,
  :network_configuration,
  :trigger_mode,
  :workflow_definition)
  SENSITIVE = []
  include Aws::Structure
end

#trigger_modeString

The trigger mode for the workflow execution.

Returns:

  • (String)


570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 570

class GetWorkflowResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :name,
  :description,
  :created_at,
  :modified_at,
  :encryption_configuration,
  :logging_configuration,
  :engine_version,
  :workflow_status,
  :definition_s3_location,
  :code,
  :code_snapshotted_at,
  :schedule_configuration,
  :role_arn,
  :network_configuration,
  :trigger_mode,
  :workflow_definition)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_arnString

The Amazon Resource Name (ARN) of the workflow.

Returns:

  • (String)


570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 570

class GetWorkflowResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :name,
  :description,
  :created_at,
  :modified_at,
  :encryption_configuration,
  :logging_configuration,
  :engine_version,
  :workflow_status,
  :definition_s3_location,
  :code,
  :code_snapshotted_at,
  :schedule_configuration,
  :role_arn,
  :network_configuration,
  :trigger_mode,
  :workflow_definition)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_definitionString

The workflow definition content.

Returns:

  • (String)


570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 570

class GetWorkflowResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :name,
  :description,
  :created_at,
  :modified_at,
  :encryption_configuration,
  :logging_configuration,
  :engine_version,
  :workflow_status,
  :definition_s3_location,
  :code,
  :code_snapshotted_at,
  :schedule_configuration,
  :role_arn,
  :network_configuration,
  :trigger_mode,
  :workflow_definition)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_statusString

The current status of the workflow.

Returns:

  • (String)


570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 570

class GetWorkflowResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :name,
  :description,
  :created_at,
  :modified_at,
  :encryption_configuration,
  :logging_configuration,
  :engine_version,
  :workflow_status,
  :definition_s3_location,
  :code,
  :code_snapshotted_at,
  :schedule_configuration,
  :role_arn,
  :network_configuration,
  :trigger_mode,
  :workflow_definition)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_versionString

The version identifier of the workflow.

Returns:

  • (String)


570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 570

class GetWorkflowResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :name,
  :description,
  :created_at,
  :modified_at,
  :encryption_configuration,
  :logging_configuration,
  :engine_version,
  :workflow_status,
  :definition_s3_location,
  :code,
  :code_snapshotted_at,
  :schedule_configuration,
  :role_arn,
  :network_configuration,
  :trigger_mode,
  :workflow_definition)
  SENSITIVE = []
  include Aws::Structure
end