Class: Aws::MWAAServerless::Types::GetWorkflowRunRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MWAAServerless::Types::GetWorkflowRunRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mwaaserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#run_id ⇒ String
The unique identifier of the workflow run to retrieve.
-
#workflow_arn ⇒ String
The Amazon Resource Name (ARN) of the workflow that contains the run.
Instance Attribute Details
#run_id ⇒ String
The unique identifier of the workflow run to retrieve.
560 561 562 563 564 565 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 560 class GetWorkflowRunRequest < Struct.new( :workflow_arn, :run_id) SENSITIVE = [] include Aws::Structure end |
#workflow_arn ⇒ String
The Amazon Resource Name (ARN) of the workflow that contains the run.
560 561 562 563 564 565 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 560 class GetWorkflowRunRequest < Struct.new( :workflow_arn, :run_id) SENSITIVE = [] include Aws::Structure end |