Class: Aws::MWAAServerless::Types::GetWorkflowRunResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mwaaserverless/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:override_parameters]

Instance Attribute Summary collapse

Instance Attribute Details

#override_parametersHash<String,Hash,Array,String,Numeric,Boolean>

Parameters that were overridden for this specific workflow run.

Returns:

  • (Hash<String,Hash,Array,String,Numeric,Boolean>)


596
597
598
599
600
601
602
603
604
605
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 596

class GetWorkflowRunResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :run_id,
  :run_type,
  :override_parameters,
  :run_detail)
  SENSITIVE = [:override_parameters]
  include Aws::Structure
end

#run_detailTypes::WorkflowRunDetail

Detailed information about the workflow run execution, including timing, status, and task instances.



596
597
598
599
600
601
602
603
604
605
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 596

class GetWorkflowRunResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :run_id,
  :run_type,
  :override_parameters,
  :run_detail)
  SENSITIVE = [:override_parameters]
  include Aws::Structure
end

#run_idString

The unique identifier of this workflow run.

Returns:

  • (String)


596
597
598
599
600
601
602
603
604
605
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 596

class GetWorkflowRunResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :run_id,
  :run_type,
  :override_parameters,
  :run_detail)
  SENSITIVE = [:override_parameters]
  include Aws::Structure
end

#run_typeString

The type of workflow run. Values are ‘ON_DEMAND` (manually triggered) or `SCHEDULED` (automatically triggered by schedule).

Returns:

  • (String)


596
597
598
599
600
601
602
603
604
605
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 596

class GetWorkflowRunResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :run_id,
  :run_type,
  :override_parameters,
  :run_detail)
  SENSITIVE = [:override_parameters]
  include Aws::Structure
end

#workflow_arnString

The Amazon Resource Name (ARN) of the workflow that contains this run.

Returns:

  • (String)


596
597
598
599
600
601
602
603
604
605
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 596

class GetWorkflowRunResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :run_id,
  :run_type,
  :override_parameters,
  :run_detail)
  SENSITIVE = [:override_parameters]
  include Aws::Structure
end

#workflow_versionString

The version of the workflow that is used for this run.

Returns:

  • (String)


596
597
598
599
600
601
602
603
604
605
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 596

class GetWorkflowRunResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :run_id,
  :run_type,
  :override_parameters,
  :run_detail)
  SENSITIVE = [:override_parameters]
  include Aws::Structure
end