Class: Aws::MWAAServerless::Types::S3Location

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mwaaserverless/types.rb

Overview

Specifies the Amazon S3 location of code artifacts that workflows use during execution.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The name of the Amazon S3 bucket.

Returns:

  • (String)


1014
1015
1016
1017
1018
1019
1020
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1014

class S3Location < Struct.new(
  :bucket,
  :object_key,
  :version_id)
  SENSITIVE = []
  include Aws::Structure
end

#object_keyString

The key of the code artifact within the Amazon S3 bucket.

Returns:

  • (String)


1014
1015
1016
1017
1018
1019
1020
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1014

class S3Location < Struct.new(
  :bucket,
  :object_key,
  :version_id)
  SENSITIVE = []
  include Aws::Structure
end

#version_idString

The version ID of the object in Amazon S3. If not specified, the latest version is used.

Returns:

  • (String)


1014
1015
1016
1017
1018
1019
1020
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1014

class S3Location < Struct.new(
  :bucket,
  :object_key,
  :version_id)
  SENSITIVE = []
  include Aws::Structure
end