Class: Aws::MWAAServerless::Types::ServiceQuotaExceededException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mwaaserverless/types.rb

Overview

The request exceeds the service quota for Amazon Managed Workflows for Apache Airflow Serverless resources. This can occur when you attempt to create more workflows than allowed, exceed concurrent workflow run limits, or surpass task execution limits. Amazon Managed Workflows for Apache Airflow Serverless implements admission control using DynamoDB-based counters to manage resource utilization across the multi-tenant environment. Contact Amazon Web Services Support to request quota increases if you need higher limits for your use case.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


1076
1077
1078
1079
1080
1081
1082
1083
1084
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1076

class ServiceQuotaExceededException < Struct.new(
  :message,
  :resource_id,
  :resource_type,
  :service_code,
  :quota_code)
  SENSITIVE = []
  include Aws::Structure
end

#quota_codeString

The code of the quota.

Returns:

  • (String)


1076
1077
1078
1079
1080
1081
1082
1083
1084
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1076

class ServiceQuotaExceededException < Struct.new(
  :message,
  :resource_id,
  :resource_type,
  :service_code,
  :quota_code)
  SENSITIVE = []
  include Aws::Structure
end

#resource_idString

The unique identifier of the resource.

Returns:

  • (String)


1076
1077
1078
1079
1080
1081
1082
1083
1084
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1076

class ServiceQuotaExceededException < Struct.new(
  :message,
  :resource_id,
  :resource_type,
  :service_code,
  :quota_code)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The type of resource affected.

Returns:

  • (String)


1076
1077
1078
1079
1080
1081
1082
1083
1084
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1076

class ServiceQuotaExceededException < Struct.new(
  :message,
  :resource_id,
  :resource_type,
  :service_code,
  :quota_code)
  SENSITIVE = []
  include Aws::Structure
end

#service_codeString

The code for the service.

Returns:

  • (String)


1076
1077
1078
1079
1080
1081
1082
1083
1084
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1076

class ServiceQuotaExceededException < Struct.new(
  :message,
  :resource_id,
  :resource_type,
  :service_code,
  :quota_code)
  SENSITIVE = []
  include Aws::Structure
end