Class: Aws::MWAAServerless::Types::StopWorkflowRunRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mwaaserverless/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#run_idString

The unique identifier of the workflow run to stop.

Returns:

  • (String)


1090
1091
1092
1093
1094
1095
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1090

class StopWorkflowRunRequest < Struct.new(
  :workflow_arn,
  :run_id)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_arnString

The Amazon Resource Name (ARN) of the workflow that contains the run you want to stop.

Returns:

  • (String)


1090
1091
1092
1093
1094
1095
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1090

class StopWorkflowRunRequest < Struct.new(
  :workflow_arn,
  :run_id)
  SENSITIVE = []
  include Aws::Structure
end