Class: Aws::MWAAServerless::Types::TaskInstanceSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::MWAAServerless::Types::TaskInstanceSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mwaaserverless/types.rb
Overview
Summary information about a task instance within a workflow run, including its status and execution details.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#duration_in_seconds ⇒ Integer
The duration of the task instance execution in seconds.
-
#operator_name ⇒ String
The name of the Apache Airflow operator used for this task instance.
-
#run_id ⇒ String
The unique identifier of the workflow run that contains this task instance.
-
#status ⇒ String
The current status of the task instance.
-
#task_instance_id ⇒ String
The unique identifier of this task instance.
-
#workflow_arn ⇒ String
The Amazon Resource Name (ARN) of the workflow that contains this task instance.
-
#workflow_version ⇒ String
The version of the workflow that contains this task instance.
Instance Attribute Details
#duration_in_seconds ⇒ Integer
The duration of the task instance execution in seconds. This value is null if the task is not complete.
1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1254 class TaskInstanceSummary < Struct.new( :workflow_arn, :workflow_version, :run_id, :task_instance_id, :status, :duration_in_seconds, :operator_name) SENSITIVE = [] include Aws::Structure end |
#operator_name ⇒ String
The name of the Apache Airflow operator used for this task instance.
1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1254 class TaskInstanceSummary < Struct.new( :workflow_arn, :workflow_version, :run_id, :task_instance_id, :status, :duration_in_seconds, :operator_name) SENSITIVE = [] include Aws::Structure end |
#run_id ⇒ String
The unique identifier of the workflow run that contains this task instance.
1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1254 class TaskInstanceSummary < Struct.new( :workflow_arn, :workflow_version, :run_id, :task_instance_id, :status, :duration_in_seconds, :operator_name) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the task instance.
1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1254 class TaskInstanceSummary < Struct.new( :workflow_arn, :workflow_version, :run_id, :task_instance_id, :status, :duration_in_seconds, :operator_name) SENSITIVE = [] include Aws::Structure end |
#task_instance_id ⇒ String
The unique identifier of this task instance.
1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1254 class TaskInstanceSummary < Struct.new( :workflow_arn, :workflow_version, :run_id, :task_instance_id, :status, :duration_in_seconds, :operator_name) SENSITIVE = [] include Aws::Structure end |
#workflow_arn ⇒ String
The Amazon Resource Name (ARN) of the workflow that contains this task instance.
1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1254 class TaskInstanceSummary < Struct.new( :workflow_arn, :workflow_version, :run_id, :task_instance_id, :status, :duration_in_seconds, :operator_name) SENSITIVE = [] include Aws::Structure end |
#workflow_version ⇒ String
The version of the workflow that contains this task instance.
1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1254 class TaskInstanceSummary < Struct.new( :workflow_arn, :workflow_version, :run_id, :task_instance_id, :status, :duration_in_seconds, :operator_name) SENSITIVE = [] include Aws::Structure end |