Class: Aws::MWAAServerless::Types::UpdateWorkflowRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MWAAServerless::Types::UpdateWorkflowRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mwaaserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ Types::Code
The location of code artifacts in Amazon S3 for the updated workflow.
-
#definition_s3_location ⇒ Types::DefinitionS3Location
The Amazon S3 location where the updated workflow definition file is stored.
-
#description ⇒ String
An updated description for the workflow.
-
#engine_version ⇒ Integer
The version of the Amazon Managed Workflows for Apache Airflow Serverless engine that you want to use for the updated workflow.
-
#logging_configuration ⇒ Types::LoggingConfiguration
Updated logging configuration for the workflow.
-
#network_configuration ⇒ Types::NetworkConfiguration
Updated network configuration for the workflow execution environment.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that Amazon Managed Workflows for Apache Airflow Serverless assumes when it executes the updated workflow.
-
#trigger_mode ⇒ String
The trigger mode for the workflow execution.
-
#workflow_arn ⇒ String
The Amazon Resource Name (ARN) of the workflow you want to update.
Instance Attribute Details
#code ⇒ Types::Code
The location of code artifacts in Amazon S3 for the updated workflow. The service copies the code from this location at the time of the request.
1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1369 class UpdateWorkflowRequest < Struct.new( :workflow_arn, :definition_s3_location, :code, :role_arn, :description, :logging_configuration, :engine_version, :network_configuration, :trigger_mode) SENSITIVE = [] include Aws::Structure end |
#definition_s3_location ⇒ Types::DefinitionS3Location
The Amazon S3 location where the updated workflow definition file is stored.
1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1369 class UpdateWorkflowRequest < Struct.new( :workflow_arn, :definition_s3_location, :code, :role_arn, :description, :logging_configuration, :engine_version, :network_configuration, :trigger_mode) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
An updated description for the workflow.
1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1369 class UpdateWorkflowRequest < Struct.new( :workflow_arn, :definition_s3_location, :code, :role_arn, :description, :logging_configuration, :engine_version, :network_configuration, :trigger_mode) SENSITIVE = [] include Aws::Structure end |
#engine_version ⇒ Integer
The version of the Amazon Managed Workflows for Apache Airflow Serverless engine that you want to use for the updated workflow.
1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1369 class UpdateWorkflowRequest < Struct.new( :workflow_arn, :definition_s3_location, :code, :role_arn, :description, :logging_configuration, :engine_version, :network_configuration, :trigger_mode) SENSITIVE = [] include Aws::Structure end |
#logging_configuration ⇒ Types::LoggingConfiguration
Updated logging configuration for the workflow.
1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1369 class UpdateWorkflowRequest < Struct.new( :workflow_arn, :definition_s3_location, :code, :role_arn, :description, :logging_configuration, :engine_version, :network_configuration, :trigger_mode) SENSITIVE = [] include Aws::Structure end |
#network_configuration ⇒ Types::NetworkConfiguration
Updated network configuration for the workflow execution environment.
1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1369 class UpdateWorkflowRequest < Struct.new( :workflow_arn, :definition_s3_location, :code, :role_arn, :description, :logging_configuration, :engine_version, :network_configuration, :trigger_mode) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that Amazon Managed Workflows for Apache Airflow Serverless assumes when it executes the updated workflow.
1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1369 class UpdateWorkflowRequest < Struct.new( :workflow_arn, :definition_s3_location, :code, :role_arn, :description, :logging_configuration, :engine_version, :network_configuration, :trigger_mode) SENSITIVE = [] include Aws::Structure end |
#trigger_mode ⇒ String
The trigger mode for the workflow execution.
1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1369 class UpdateWorkflowRequest < Struct.new( :workflow_arn, :definition_s3_location, :code, :role_arn, :description, :logging_configuration, :engine_version, :network_configuration, :trigger_mode) SENSITIVE = [] include Aws::Structure end |
#workflow_arn ⇒ String
The Amazon Resource Name (ARN) of the workflow you want to update.
1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1369 class UpdateWorkflowRequest < Struct.new( :workflow_arn, :definition_s3_location, :code, :role_arn, :description, :logging_configuration, :engine_version, :network_configuration, :trigger_mode) SENSITIVE = [] include Aws::Structure end |