Class: Aws::MWAAServerless::Types::UpdateWorkflowResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MWAAServerless::Types::UpdateWorkflowResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mwaaserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#modified_at ⇒ Time
The timestamp when the workflow was last modified, in ISO 8601 date-time format.
-
#warnings ⇒ Array<String>
Warning messages generated during workflow update.
-
#workflow_arn ⇒ String
The Amazon Resource Name (ARN) of the updated workflow.
-
#workflow_version ⇒ String
The version identifier of the updated workflow.
Instance Attribute Details
#modified_at ⇒ Time
The timestamp when the workflow was last modified, in ISO 8601 date-time format.
1325 1326 1327 1328 1329 1330 1331 1332 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1325 class UpdateWorkflowResponse < Struct.new( :workflow_arn, :modified_at, :workflow_version, :warnings) SENSITIVE = [] include Aws::Structure end |
#warnings ⇒ Array<String>
Warning messages generated during workflow update.
1325 1326 1327 1328 1329 1330 1331 1332 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1325 class UpdateWorkflowResponse < Struct.new( :workflow_arn, :modified_at, :workflow_version, :warnings) SENSITIVE = [] include Aws::Structure end |
#workflow_arn ⇒ String
The Amazon Resource Name (ARN) of the updated workflow.
1325 1326 1327 1328 1329 1330 1331 1332 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1325 class UpdateWorkflowResponse < Struct.new( :workflow_arn, :modified_at, :workflow_version, :warnings) SENSITIVE = [] include Aws::Structure end |
#workflow_version ⇒ String
The version identifier of the updated workflow.
1325 1326 1327 1328 1329 1330 1331 1332 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1325 class UpdateWorkflowResponse < Struct.new( :workflow_arn, :modified_at, :workflow_version, :warnings) SENSITIVE = [] include Aws::Structure end |