Class: Aws::MWAAServerless::Types::ValidationExceptionField

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mwaaserverless/types.rb

Overview

Contains information about a field that failed validation, including the field name and a descriptive error message.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

A message that describes why the field failed validation.

Returns:

  • (String)


1454
1455
1456
1457
1458
1459
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1454

class ValidationExceptionField < Struct.new(
  :name,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the field that failed validation.

Returns:

  • (String)


1454
1455
1456
1457
1458
1459
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1454

class ValidationExceptionField < Struct.new(
  :name,
  :message)
  SENSITIVE = []
  include Aws::Structure
end