Class: Aws::MWAAServerless::Types::GetWorkflowResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mwaaserverless/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp when the workflow was created, in ISO 8601 date-time format.

Returns:

  • (Time)


528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 528

class GetWorkflowResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :name,
  :description,
  :created_at,
  :modified_at,
  :encryption_configuration,
  :logging_configuration,
  :engine_version,
  :workflow_status,
  :definition_s3_location,
  :schedule_configuration,
  :role_arn,
  :network_configuration,
  :trigger_mode,
  :workflow_definition)
  SENSITIVE = []
  include Aws::Structure
end

#definition_s3_locationTypes::DefinitionS3Location

The Amazon S3 location of the workflow definition file.



528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 528

class GetWorkflowResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :name,
  :description,
  :created_at,
  :modified_at,
  :encryption_configuration,
  :logging_configuration,
  :engine_version,
  :workflow_status,
  :definition_s3_location,
  :schedule_configuration,
  :role_arn,
  :network_configuration,
  :trigger_mode,
  :workflow_definition)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the workflow.

Returns:

  • (String)


528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 528

class GetWorkflowResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :name,
  :description,
  :created_at,
  :modified_at,
  :encryption_configuration,
  :logging_configuration,
  :engine_version,
  :workflow_status,
  :definition_s3_location,
  :schedule_configuration,
  :role_arn,
  :network_configuration,
  :trigger_mode,
  :workflow_definition)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_configurationTypes::EncryptionConfiguration

The encryption configuration for the workflow.



528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 528

class GetWorkflowResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :name,
  :description,
  :created_at,
  :modified_at,
  :encryption_configuration,
  :logging_configuration,
  :engine_version,
  :workflow_status,
  :definition_s3_location,
  :schedule_configuration,
  :role_arn,
  :network_configuration,
  :trigger_mode,
  :workflow_definition)
  SENSITIVE = []
  include Aws::Structure
end

#engine_versionInteger

The version of the Amazon Managed Workflows for Apache Airflow Serverless engine that this workflow uses.

Returns:

  • (Integer)


528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 528

class GetWorkflowResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :name,
  :description,
  :created_at,
  :modified_at,
  :encryption_configuration,
  :logging_configuration,
  :engine_version,
  :workflow_status,
  :definition_s3_location,
  :schedule_configuration,
  :role_arn,
  :network_configuration,
  :trigger_mode,
  :workflow_definition)
  SENSITIVE = []
  include Aws::Structure
end

#logging_configurationTypes::LoggingConfiguration

The logging configuration for the workflow.



528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 528

class GetWorkflowResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :name,
  :description,
  :created_at,
  :modified_at,
  :encryption_configuration,
  :logging_configuration,
  :engine_version,
  :workflow_status,
  :definition_s3_location,
  :schedule_configuration,
  :role_arn,
  :network_configuration,
  :trigger_mode,
  :workflow_definition)
  SENSITIVE = []
  include Aws::Structure
end

#modified_atTime

The timestamp when the workflow was last modified, in ISO 8601 date-time format.

Returns:

  • (Time)


528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 528

class GetWorkflowResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :name,
  :description,
  :created_at,
  :modified_at,
  :encryption_configuration,
  :logging_configuration,
  :engine_version,
  :workflow_status,
  :definition_s3_location,
  :schedule_configuration,
  :role_arn,
  :network_configuration,
  :trigger_mode,
  :workflow_definition)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the workflow.

Returns:

  • (String)


528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 528

class GetWorkflowResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :name,
  :description,
  :created_at,
  :modified_at,
  :encryption_configuration,
  :logging_configuration,
  :engine_version,
  :workflow_status,
  :definition_s3_location,
  :schedule_configuration,
  :role_arn,
  :network_configuration,
  :trigger_mode,
  :workflow_definition)
  SENSITIVE = []
  include Aws::Structure
end

#network_configurationTypes::NetworkConfiguration

The network configuration for the workflow execution environment.



528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 528

class GetWorkflowResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :name,
  :description,
  :created_at,
  :modified_at,
  :encryption_configuration,
  :logging_configuration,
  :engine_version,
  :workflow_status,
  :definition_s3_location,
  :schedule_configuration,
  :role_arn,
  :network_configuration,
  :trigger_mode,
  :workflow_definition)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of the IAM role used for workflow execution.

Returns:

  • (String)


528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 528

class GetWorkflowResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :name,
  :description,
  :created_at,
  :modified_at,
  :encryption_configuration,
  :logging_configuration,
  :engine_version,
  :workflow_status,
  :definition_s3_location,
  :schedule_configuration,
  :role_arn,
  :network_configuration,
  :trigger_mode,
  :workflow_definition)
  SENSITIVE = []
  include Aws::Structure
end

#schedule_configurationTypes::ScheduleConfiguration

The schedule configuration for the workflow, including cron expressions for automated execution. Amazon Managed Workflows for Apache Airflow Serverless uses EventBridge Scheduler for cost-effective, timezone-aware scheduling. When a workflow includes schedule information in its YAML definition, the service automatically configures the appropriate triggers for automated execution. Only one version of a workflow can have an active schedule at any given time.



528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 528

class GetWorkflowResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :name,
  :description,
  :created_at,
  :modified_at,
  :encryption_configuration,
  :logging_configuration,
  :engine_version,
  :workflow_status,
  :definition_s3_location,
  :schedule_configuration,
  :role_arn,
  :network_configuration,
  :trigger_mode,
  :workflow_definition)
  SENSITIVE = []
  include Aws::Structure
end

#trigger_modeString

The trigger mode for the workflow execution.

Returns:

  • (String)


528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 528

class GetWorkflowResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :name,
  :description,
  :created_at,
  :modified_at,
  :encryption_configuration,
  :logging_configuration,
  :engine_version,
  :workflow_status,
  :definition_s3_location,
  :schedule_configuration,
  :role_arn,
  :network_configuration,
  :trigger_mode,
  :workflow_definition)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_arnString

The Amazon Resource Name (ARN) of the workflow.

Returns:

  • (String)


528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 528

class GetWorkflowResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :name,
  :description,
  :created_at,
  :modified_at,
  :encryption_configuration,
  :logging_configuration,
  :engine_version,
  :workflow_status,
  :definition_s3_location,
  :schedule_configuration,
  :role_arn,
  :network_configuration,
  :trigger_mode,
  :workflow_definition)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_definitionString

The workflow definition content.

Returns:

  • (String)


528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 528

class GetWorkflowResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :name,
  :description,
  :created_at,
  :modified_at,
  :encryption_configuration,
  :logging_configuration,
  :engine_version,
  :workflow_status,
  :definition_s3_location,
  :schedule_configuration,
  :role_arn,
  :network_configuration,
  :trigger_mode,
  :workflow_definition)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_statusString

The current status of the workflow.

Returns:

  • (String)


528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 528

class GetWorkflowResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :name,
  :description,
  :created_at,
  :modified_at,
  :encryption_configuration,
  :logging_configuration,
  :engine_version,
  :workflow_status,
  :definition_s3_location,
  :schedule_configuration,
  :role_arn,
  :network_configuration,
  :trigger_mode,
  :workflow_definition)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_versionString

The version identifier of the workflow.

Returns:

  • (String)


528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 528

class GetWorkflowResponse < Struct.new(
  :workflow_arn,
  :workflow_version,
  :name,
  :description,
  :created_at,
  :modified_at,
  :encryption_configuration,
  :logging_configuration,
  :engine_version,
  :workflow_status,
  :definition_s3_location,
  :schedule_configuration,
  :role_arn,
  :network_configuration,
  :trigger_mode,
  :workflow_definition)
  SENSITIVE = []
  include Aws::Structure
end