Class: Aws::MWAAServerless::Types::GetWorkflowResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MWAAServerless::Types::GetWorkflowResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mwaaserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp when the workflow was created, in ISO 8601 date-time format.
-
#definition_s3_location ⇒ Types::DefinitionS3Location
The Amazon S3 location of the workflow definition file.
-
#description ⇒ String
The description of the workflow.
-
#encryption_configuration ⇒ Types::EncryptionConfiguration
The encryption configuration for the workflow.
-
#engine_version ⇒ Integer
The version of the Amazon Managed Workflows for Apache Airflow Serverless engine that this workflow uses.
-
#logging_configuration ⇒ Types::LoggingConfiguration
The logging configuration for the workflow.
-
#modified_at ⇒ Time
The timestamp when the workflow was last modified, in ISO 8601 date-time format.
-
#name ⇒ String
The name of the workflow.
-
#network_configuration ⇒ Types::NetworkConfiguration
The network configuration for the workflow execution environment.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role used for workflow execution.
-
#schedule_configuration ⇒ Types::ScheduleConfiguration
The schedule configuration for the workflow, including cron expressions for automated execution.
-
#trigger_mode ⇒ String
The trigger mode for the workflow execution.
-
#workflow_arn ⇒ String
The Amazon Resource Name (ARN) of the workflow.
-
#workflow_definition ⇒ String
The workflow definition content.
-
#workflow_status ⇒ String
The current status of the workflow.
-
#workflow_version ⇒ String
The version identifier of the workflow.
Instance Attribute Details
#created_at ⇒ Time
The timestamp when the workflow was created, in ISO 8601 date-time format.
528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 528 class GetWorkflowResponse < Struct.new( :workflow_arn, :workflow_version, :name, :description, :created_at, :modified_at, :encryption_configuration, :logging_configuration, :engine_version, :workflow_status, :definition_s3_location, :schedule_configuration, :role_arn, :network_configuration, :trigger_mode, :workflow_definition) SENSITIVE = [] include Aws::Structure end |
#definition_s3_location ⇒ Types::DefinitionS3Location
The Amazon S3 location of the workflow definition file.
528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 528 class GetWorkflowResponse < Struct.new( :workflow_arn, :workflow_version, :name, :description, :created_at, :modified_at, :encryption_configuration, :logging_configuration, :engine_version, :workflow_status, :definition_s3_location, :schedule_configuration, :role_arn, :network_configuration, :trigger_mode, :workflow_definition) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the workflow.
528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 528 class GetWorkflowResponse < Struct.new( :workflow_arn, :workflow_version, :name, :description, :created_at, :modified_at, :encryption_configuration, :logging_configuration, :engine_version, :workflow_status, :definition_s3_location, :schedule_configuration, :role_arn, :network_configuration, :trigger_mode, :workflow_definition) SENSITIVE = [] include Aws::Structure end |
#encryption_configuration ⇒ Types::EncryptionConfiguration
The encryption configuration for the workflow.
528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 528 class GetWorkflowResponse < Struct.new( :workflow_arn, :workflow_version, :name, :description, :created_at, :modified_at, :encryption_configuration, :logging_configuration, :engine_version, :workflow_status, :definition_s3_location, :schedule_configuration, :role_arn, :network_configuration, :trigger_mode, :workflow_definition) SENSITIVE = [] include Aws::Structure end |
#engine_version ⇒ Integer
The version of the Amazon Managed Workflows for Apache Airflow Serverless engine that this workflow uses.
528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 528 class GetWorkflowResponse < Struct.new( :workflow_arn, :workflow_version, :name, :description, :created_at, :modified_at, :encryption_configuration, :logging_configuration, :engine_version, :workflow_status, :definition_s3_location, :schedule_configuration, :role_arn, :network_configuration, :trigger_mode, :workflow_definition) SENSITIVE = [] include Aws::Structure end |
#logging_configuration ⇒ Types::LoggingConfiguration
The logging configuration for the workflow.
528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 528 class GetWorkflowResponse < Struct.new( :workflow_arn, :workflow_version, :name, :description, :created_at, :modified_at, :encryption_configuration, :logging_configuration, :engine_version, :workflow_status, :definition_s3_location, :schedule_configuration, :role_arn, :network_configuration, :trigger_mode, :workflow_definition) SENSITIVE = [] include Aws::Structure end |
#modified_at ⇒ Time
The timestamp when the workflow was last modified, in ISO 8601 date-time format.
528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 528 class GetWorkflowResponse < Struct.new( :workflow_arn, :workflow_version, :name, :description, :created_at, :modified_at, :encryption_configuration, :logging_configuration, :engine_version, :workflow_status, :definition_s3_location, :schedule_configuration, :role_arn, :network_configuration, :trigger_mode, :workflow_definition) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the workflow.
528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 528 class GetWorkflowResponse < Struct.new( :workflow_arn, :workflow_version, :name, :description, :created_at, :modified_at, :encryption_configuration, :logging_configuration, :engine_version, :workflow_status, :definition_s3_location, :schedule_configuration, :role_arn, :network_configuration, :trigger_mode, :workflow_definition) SENSITIVE = [] include Aws::Structure end |
#network_configuration ⇒ Types::NetworkConfiguration
The network configuration for the workflow execution environment.
528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 528 class GetWorkflowResponse < Struct.new( :workflow_arn, :workflow_version, :name, :description, :created_at, :modified_at, :encryption_configuration, :logging_configuration, :engine_version, :workflow_status, :definition_s3_location, :schedule_configuration, :role_arn, :network_configuration, :trigger_mode, :workflow_definition) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role used for workflow execution.
528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 528 class GetWorkflowResponse < Struct.new( :workflow_arn, :workflow_version, :name, :description, :created_at, :modified_at, :encryption_configuration, :logging_configuration, :engine_version, :workflow_status, :definition_s3_location, :schedule_configuration, :role_arn, :network_configuration, :trigger_mode, :workflow_definition) SENSITIVE = [] include Aws::Structure end |
#schedule_configuration ⇒ Types::ScheduleConfiguration
The schedule configuration for the workflow, including cron expressions for automated execution. Amazon Managed Workflows for Apache Airflow Serverless uses EventBridge Scheduler for cost-effective, timezone-aware scheduling. When a workflow includes schedule information in its YAML definition, the service automatically configures the appropriate triggers for automated execution. Only one version of a workflow can have an active schedule at any given time.
528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 528 class GetWorkflowResponse < Struct.new( :workflow_arn, :workflow_version, :name, :description, :created_at, :modified_at, :encryption_configuration, :logging_configuration, :engine_version, :workflow_status, :definition_s3_location, :schedule_configuration, :role_arn, :network_configuration, :trigger_mode, :workflow_definition) SENSITIVE = [] include Aws::Structure end |
#trigger_mode ⇒ String
The trigger mode for the workflow execution.
528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 528 class GetWorkflowResponse < Struct.new( :workflow_arn, :workflow_version, :name, :description, :created_at, :modified_at, :encryption_configuration, :logging_configuration, :engine_version, :workflow_status, :definition_s3_location, :schedule_configuration, :role_arn, :network_configuration, :trigger_mode, :workflow_definition) SENSITIVE = [] include Aws::Structure end |
#workflow_arn ⇒ String
The Amazon Resource Name (ARN) of the workflow.
528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 528 class GetWorkflowResponse < Struct.new( :workflow_arn, :workflow_version, :name, :description, :created_at, :modified_at, :encryption_configuration, :logging_configuration, :engine_version, :workflow_status, :definition_s3_location, :schedule_configuration, :role_arn, :network_configuration, :trigger_mode, :workflow_definition) SENSITIVE = [] include Aws::Structure end |
#workflow_definition ⇒ String
The workflow definition content.
528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 528 class GetWorkflowResponse < Struct.new( :workflow_arn, :workflow_version, :name, :description, :created_at, :modified_at, :encryption_configuration, :logging_configuration, :engine_version, :workflow_status, :definition_s3_location, :schedule_configuration, :role_arn, :network_configuration, :trigger_mode, :workflow_definition) SENSITIVE = [] include Aws::Structure end |
#workflow_status ⇒ String
The current status of the workflow.
528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 528 class GetWorkflowResponse < Struct.new( :workflow_arn, :workflow_version, :name, :description, :created_at, :modified_at, :encryption_configuration, :logging_configuration, :engine_version, :workflow_status, :definition_s3_location, :schedule_configuration, :role_arn, :network_configuration, :trigger_mode, :workflow_definition) SENSITIVE = [] include Aws::Structure end |
#workflow_version ⇒ String
The version identifier of the workflow.
528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 528 class GetWorkflowResponse < Struct.new( :workflow_arn, :workflow_version, :name, :description, :created_at, :modified_at, :encryption_configuration, :logging_configuration, :engine_version, :workflow_status, :definition_s3_location, :schedule_configuration, :role_arn, :network_configuration, :trigger_mode, :workflow_definition) SENSITIVE = [] include Aws::Structure end |