Class: Aws::MWAAServerless::Types::GetWorkflowRunResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MWAAServerless::Types::GetWorkflowRunResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mwaaserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:override_parameters]
Instance Attribute Summary collapse
-
#override_parameters ⇒ Hash<String,Hash,Array,String,Numeric,Boolean>
Parameters that were overridden for this specific workflow run.
-
#run_detail ⇒ Types::WorkflowRunDetail
Detailed information about the workflow run execution, including timing, status, and task instances.
-
#run_id ⇒ String
The unique identifier of this workflow run.
-
#run_type ⇒ String
The type of workflow run.
-
#workflow_arn ⇒ String
The Amazon Resource Name (ARN) of the workflow that contains this run.
-
#workflow_version ⇒ String
The version of the workflow that is used for this run.
Instance Attribute Details
#override_parameters ⇒ Hash<String,Hash,Array,String,Numeric,Boolean>
Parameters that were overridden for this specific workflow run.
596 597 598 599 600 601 602 603 604 605 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 596 class GetWorkflowRunResponse < Struct.new( :workflow_arn, :workflow_version, :run_id, :run_type, :override_parameters, :run_detail) SENSITIVE = [:override_parameters] include Aws::Structure end |
#run_detail ⇒ Types::WorkflowRunDetail
Detailed information about the workflow run execution, including timing, status, and task instances.
596 597 598 599 600 601 602 603 604 605 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 596 class GetWorkflowRunResponse < Struct.new( :workflow_arn, :workflow_version, :run_id, :run_type, :override_parameters, :run_detail) SENSITIVE = [:override_parameters] include Aws::Structure end |
#run_id ⇒ String
The unique identifier of this workflow run.
596 597 598 599 600 601 602 603 604 605 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 596 class GetWorkflowRunResponse < Struct.new( :workflow_arn, :workflow_version, :run_id, :run_type, :override_parameters, :run_detail) SENSITIVE = [:override_parameters] include Aws::Structure end |
#run_type ⇒ String
The type of workflow run. Values are ‘ON_DEMAND` (manually triggered) or `SCHEDULED` (automatically triggered by schedule).
596 597 598 599 600 601 602 603 604 605 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 596 class GetWorkflowRunResponse < Struct.new( :workflow_arn, :workflow_version, :run_id, :run_type, :override_parameters, :run_detail) SENSITIVE = [:override_parameters] include Aws::Structure end |
#workflow_arn ⇒ String
The Amazon Resource Name (ARN) of the workflow that contains this run.
596 597 598 599 600 601 602 603 604 605 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 596 class GetWorkflowRunResponse < Struct.new( :workflow_arn, :workflow_version, :run_id, :run_type, :override_parameters, :run_detail) SENSITIVE = [:override_parameters] include Aws::Structure end |
#workflow_version ⇒ String
The version of the workflow that is used for this run.
596 597 598 599 600 601 602 603 604 605 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 596 class GetWorkflowRunResponse < Struct.new( :workflow_arn, :workflow_version, :run_id, :run_type, :override_parameters, :run_detail) SENSITIVE = [:override_parameters] include Aws::Structure end |