Class: Aws::MWAAServerless::Types::S3Location
- Inherits:
-
Struct
- Object
- Struct
- Aws::MWAAServerless::Types::S3Location
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mwaaserverless/types.rb
Overview
Specifies the Amazon S3 location of code artifacts that workflows use during execution.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The name of the Amazon S3 bucket.
-
#object_key ⇒ String
The key of the code artifact within the Amazon S3 bucket.
-
#version_id ⇒ String
The version ID of the object in Amazon S3.
Instance Attribute Details
#bucket ⇒ String
The name of the Amazon S3 bucket.
1014 1015 1016 1017 1018 1019 1020 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1014 class S3Location < Struct.new( :bucket, :object_key, :version_id) SENSITIVE = [] include Aws::Structure end |
#object_key ⇒ String
The key of the code artifact within the Amazon S3 bucket.
1014 1015 1016 1017 1018 1019 1020 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1014 class S3Location < Struct.new( :bucket, :object_key, :version_id) SENSITIVE = [] include Aws::Structure end |
#version_id ⇒ String
The version ID of the object in Amazon S3. If not specified, the latest version is used.
1014 1015 1016 1017 1018 1019 1020 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1014 class S3Location < Struct.new( :bucket, :object_key, :version_id) SENSITIVE = [] include Aws::Structure end |