Class: Aws::MWAAServerless::Types::ServiceQuotaExceededException
- Inherits:
-
Struct
- Object
- Struct
- Aws::MWAAServerless::Types::ServiceQuotaExceededException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mwaaserverless/types.rb
Overview
The request exceeds the service quota for Amazon Managed Workflows for Apache Airflow Serverless resources. This can occur when you attempt to create more workflows than allowed, exceed concurrent workflow run limits, or surpass task execution limits. Amazon Managed Workflows for Apache Airflow Serverless implements admission control using DynamoDB-based counters to manage resource utilization across the multi-tenant environment. Contact Amazon Web Services Support to request quota increases if you need higher limits for your use case.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #message ⇒ String
-
#quota_code ⇒ String
The code of the quota.
-
#resource_id ⇒ String
The unique identifier of the resource.
-
#resource_type ⇒ String
The type of resource affected.
-
#service_code ⇒ String
The code for the service.
Instance Attribute Details
#message ⇒ String
1076 1077 1078 1079 1080 1081 1082 1083 1084 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1076 class ServiceQuotaExceededException < Struct.new( :message, :resource_id, :resource_type, :service_code, :quota_code) SENSITIVE = [] include Aws::Structure end |
#quota_code ⇒ String
The code of the quota.
1076 1077 1078 1079 1080 1081 1082 1083 1084 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1076 class ServiceQuotaExceededException < Struct.new( :message, :resource_id, :resource_type, :service_code, :quota_code) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
The unique identifier of the resource.
1076 1077 1078 1079 1080 1081 1082 1083 1084 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1076 class ServiceQuotaExceededException < Struct.new( :message, :resource_id, :resource_type, :service_code, :quota_code) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of resource affected.
1076 1077 1078 1079 1080 1081 1082 1083 1084 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1076 class ServiceQuotaExceededException < Struct.new( :message, :resource_id, :resource_type, :service_code, :quota_code) SENSITIVE = [] include Aws::Structure end |
#service_code ⇒ String
The code for the service.
1076 1077 1078 1079 1080 1081 1082 1083 1084 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1076 class ServiceQuotaExceededException < Struct.new( :message, :resource_id, :resource_type, :service_code, :quota_code) SENSITIVE = [] include Aws::Structure end |