Class: Aws::MWAAServerless::Types::StartWorkflowRunRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MWAAServerless::Types::StartWorkflowRunRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mwaaserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:override_parameters]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#override_parameters ⇒ Hash<String,Hash,Array,String,Numeric,Boolean>
Optional parameters to override default workflow parameters for this specific run.
-
#workflow_arn ⇒ String
The Amazon Resource Name (ARN) of the workflow you want to run.
-
#workflow_version ⇒ String
Optional.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. This token prevents duplicate workflow run requests.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
1046 1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1046 class StartWorkflowRunRequest < Struct.new( :workflow_arn, :client_token, :override_parameters, :workflow_version) SENSITIVE = [:override_parameters] include Aws::Structure end |
#override_parameters ⇒ Hash<String,Hash,Array,String,Numeric,Boolean>
Optional parameters to override default workflow parameters for this specific run. These parameters are passed to the workflow during execution and can be used to customize behavior without modifying the workflow definition. Parameters are made available as environment variables to tasks and you can reference them within the YAML workflow definition using standard parameter substitution syntax.
1046 1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1046 class StartWorkflowRunRequest < Struct.new( :workflow_arn, :client_token, :override_parameters, :workflow_version) SENSITIVE = [:override_parameters] include Aws::Structure end |
#workflow_arn ⇒ String
The Amazon Resource Name (ARN) of the workflow you want to run.
1046 1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1046 class StartWorkflowRunRequest < Struct.new( :workflow_arn, :client_token, :override_parameters, :workflow_version) SENSITIVE = [:override_parameters] include Aws::Structure end |
#workflow_version ⇒ String
Optional. The specific version of the workflow to execute. If not specified, the latest version is used.
1046 1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1046 class StartWorkflowRunRequest < Struct.new( :workflow_arn, :client_token, :override_parameters, :workflow_version) SENSITIVE = [:override_parameters] include Aws::Structure end |