Class: Aws::MWAAServerless::Types::StopWorkflowRunRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MWAAServerless::Types::StopWorkflowRunRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mwaaserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#run_id ⇒ String
The unique identifier of the workflow run to stop.
-
#workflow_arn ⇒ String
The Amazon Resource Name (ARN) of the workflow that contains the run you want to stop.
Instance Attribute Details
#run_id ⇒ String
The unique identifier of the workflow run to stop.
1090 1091 1092 1093 1094 1095 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1090 class StopWorkflowRunRequest < Struct.new( :workflow_arn, :run_id) SENSITIVE = [] include Aws::Structure end |
#workflow_arn ⇒ String
The Amazon Resource Name (ARN) of the workflow that contains the run you want to stop.
1090 1091 1092 1093 1094 1095 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1090 class StopWorkflowRunRequest < Struct.new( :workflow_arn, :run_id) SENSITIVE = [] include Aws::Structure end |