Class: Aws::MWAAServerless::Types::UpdateWorkflowRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mwaaserverless/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#definition_s3_locationTypes::DefinitionS3Location

The Amazon S3 location where the updated workflow definition file is stored.



1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1293

class UpdateWorkflowRequest < Struct.new(
  :workflow_arn,
  :definition_s3_location,
  :role_arn,
  :description,
  :logging_configuration,
  :engine_version,
  :network_configuration,
  :trigger_mode)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

An updated description for the workflow.

Returns:

  • (String)


1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1293

class UpdateWorkflowRequest < Struct.new(
  :workflow_arn,
  :definition_s3_location,
  :role_arn,
  :description,
  :logging_configuration,
  :engine_version,
  :network_configuration,
  :trigger_mode)
  SENSITIVE = []
  include Aws::Structure
end

#engine_versionInteger

The version of the Amazon Managed Workflows for Apache Airflow Serverless engine that you want to use for the updated workflow.

Returns:

  • (Integer)


1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1293

class UpdateWorkflowRequest < Struct.new(
  :workflow_arn,
  :definition_s3_location,
  :role_arn,
  :description,
  :logging_configuration,
  :engine_version,
  :network_configuration,
  :trigger_mode)
  SENSITIVE = []
  include Aws::Structure
end

#logging_configurationTypes::LoggingConfiguration

Updated logging configuration for the workflow.



1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1293

class UpdateWorkflowRequest < Struct.new(
  :workflow_arn,
  :definition_s3_location,
  :role_arn,
  :description,
  :logging_configuration,
  :engine_version,
  :network_configuration,
  :trigger_mode)
  SENSITIVE = []
  include Aws::Structure
end

#network_configurationTypes::NetworkConfiguration

Updated network configuration for the workflow execution environment.



1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1293

class UpdateWorkflowRequest < Struct.new(
  :workflow_arn,
  :definition_s3_location,
  :role_arn,
  :description,
  :logging_configuration,
  :engine_version,
  :network_configuration,
  :trigger_mode)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of the IAM role that Amazon Managed Workflows for Apache Airflow Serverless assumes when it executes the updated workflow.

Returns:

  • (String)


1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1293

class UpdateWorkflowRequest < Struct.new(
  :workflow_arn,
  :definition_s3_location,
  :role_arn,
  :description,
  :logging_configuration,
  :engine_version,
  :network_configuration,
  :trigger_mode)
  SENSITIVE = []
  include Aws::Structure
end

#trigger_modeString

The trigger mode for the workflow execution.

Returns:

  • (String)


1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1293

class UpdateWorkflowRequest < Struct.new(
  :workflow_arn,
  :definition_s3_location,
  :role_arn,
  :description,
  :logging_configuration,
  :engine_version,
  :network_configuration,
  :trigger_mode)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_arnString

The Amazon Resource Name (ARN) of the workflow you want to update.

Returns:

  • (String)


1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1293

class UpdateWorkflowRequest < Struct.new(
  :workflow_arn,
  :definition_s3_location,
  :role_arn,
  :description,
  :logging_configuration,
  :engine_version,
  :network_configuration,
  :trigger_mode)
  SENSITIVE = []
  include Aws::Structure
end