Class: Aws::MWAAServerless::Types::UpdateWorkflowRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MWAAServerless::Types::UpdateWorkflowRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mwaaserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#definition_s3_location ⇒ Types::DefinitionS3Location
The Amazon S3 location where the updated workflow definition file is stored.
-
#description ⇒ String
An updated description for the workflow.
-
#engine_version ⇒ Integer
The version of the Amazon Managed Workflows for Apache Airflow Serverless engine that you want to use for the updated workflow.
-
#logging_configuration ⇒ Types::LoggingConfiguration
Updated logging configuration for the workflow.
-
#network_configuration ⇒ Types::NetworkConfiguration
Updated network configuration for the workflow execution environment.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that Amazon Managed Workflows for Apache Airflow Serverless assumes when it executes the updated workflow.
-
#trigger_mode ⇒ String
The trigger mode for the workflow execution.
-
#workflow_arn ⇒ String
The Amazon Resource Name (ARN) of the workflow you want to update.
Instance Attribute Details
#definition_s3_location ⇒ Types::DefinitionS3Location
The Amazon S3 location where the updated workflow definition file is stored.
1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1293 class UpdateWorkflowRequest < Struct.new( :workflow_arn, :definition_s3_location, :role_arn, :description, :logging_configuration, :engine_version, :network_configuration, :trigger_mode) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
An updated description for the workflow.
1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1293 class UpdateWorkflowRequest < Struct.new( :workflow_arn, :definition_s3_location, :role_arn, :description, :logging_configuration, :engine_version, :network_configuration, :trigger_mode) SENSITIVE = [] include Aws::Structure end |
#engine_version ⇒ Integer
The version of the Amazon Managed Workflows for Apache Airflow Serverless engine that you want to use for the updated workflow.
1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1293 class UpdateWorkflowRequest < Struct.new( :workflow_arn, :definition_s3_location, :role_arn, :description, :logging_configuration, :engine_version, :network_configuration, :trigger_mode) SENSITIVE = [] include Aws::Structure end |
#logging_configuration ⇒ Types::LoggingConfiguration
Updated logging configuration for the workflow.
1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1293 class UpdateWorkflowRequest < Struct.new( :workflow_arn, :definition_s3_location, :role_arn, :description, :logging_configuration, :engine_version, :network_configuration, :trigger_mode) SENSITIVE = [] include Aws::Structure end |
#network_configuration ⇒ Types::NetworkConfiguration
Updated network configuration for the workflow execution environment.
1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1293 class UpdateWorkflowRequest < Struct.new( :workflow_arn, :definition_s3_location, :role_arn, :description, :logging_configuration, :engine_version, :network_configuration, :trigger_mode) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that Amazon Managed Workflows for Apache Airflow Serverless assumes when it executes the updated workflow.
1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1293 class UpdateWorkflowRequest < Struct.new( :workflow_arn, :definition_s3_location, :role_arn, :description, :logging_configuration, :engine_version, :network_configuration, :trigger_mode) SENSITIVE = [] include Aws::Structure end |
#trigger_mode ⇒ String
The trigger mode for the workflow execution.
1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1293 class UpdateWorkflowRequest < Struct.new( :workflow_arn, :definition_s3_location, :role_arn, :description, :logging_configuration, :engine_version, :network_configuration, :trigger_mode) SENSITIVE = [] include Aws::Structure end |
#workflow_arn ⇒ String
The Amazon Resource Name (ARN) of the workflow you want to update.
1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1293 class UpdateWorkflowRequest < Struct.new( :workflow_arn, :definition_s3_location, :role_arn, :description, :logging_configuration, :engine_version, :network_configuration, :trigger_mode) SENSITIVE = [] include Aws::Structure end |