Class: Aws::MWAAServerless::Types::ValidationException
- Inherits:
-
Struct
- Object
- Struct
- Aws::MWAAServerless::Types::ValidationException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mwaaserverless/types.rb
Overview
The specified request parameters are invalid, missing, or inconsistent with Amazon Managed Workflows for Apache Airflow Serverless service requirements. This can occur when workflow definitions contain unsupported operators, when required IAM permissions are missing, when S3 locations are inaccessible, or when network configurations are invalid. The service validates workflow definitions, execution roles, and resource configurations to ensure compatibility with the managed Airflow environment and security requirements.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#field_list ⇒ Array<Types::ValidationExceptionField>
The fields that failed validation.
- #message ⇒ String
-
#reason ⇒ String
The reason the request failed validation.
Instance Attribute Details
#field_list ⇒ Array<Types::ValidationExceptionField>
The fields that failed validation.
1433 1434 1435 1436 1437 1438 1439 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1433 class ValidationException < Struct.new( :message, :reason, :field_list) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
1433 1434 1435 1436 1437 1438 1439 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1433 class ValidationException < Struct.new( :message, :reason, :field_list) SENSITIVE = [] include Aws::Structure end |
#reason ⇒ String
The reason the request failed validation.
1433 1434 1435 1436 1437 1438 1439 |
# File 'lib/aws-sdk-mwaaserverless/types.rb', line 1433 class ValidationException < Struct.new( :message, :reason, :field_list) SENSITIVE = [] include Aws::Structure end |